Package: butcher
Title: Model Butcher
Version: 0.3.4
Authors@R: c(
    person("Joyce", "Cahoon", , "joyceyu48@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0001-7217-4702")),
    person("Davis", "Vaughan", , "davis@posit.co", role = "aut"),
    person("Max", "Kuhn", , "max@posit.co", role = "aut"),
    person("Alex", "Hayes", , "alexpghayes@gmail.com", role = "aut"),
    person("Julia", "Silge", , "julia.silge@posit.co", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-3671-836X")),
    person("Posit, PBC", role = c("cph", "fnd"))
  )
Description: Provides a set of S3 generics to axe components of fitted
    model objects and help reduce the size of model objects saved to disk.
License: MIT + file LICENSE
URL: https://butcher.tidymodels.org/,
        https://github.com/tidymodels/butcher
BugReports: https://github.com/tidymodels/butcher/issues
Depends: R (>= 3.6.0)
Imports: cli (>= 3.3.0), lobstr (>= 1.1.2), methods, purrr (>= 0.3.4),
        rlang (>= 1.0.2), tibble (>= 3.1.7), utils, vctrs (>= 0.4.1)
Suggests: C50, caret, clisymbols, ClusterR, clustMixType, covr, dbarts,
        ddalpha, dimRed, dplyr, e1071, earth, flexsurv, fs, ipred,
        kernlab, kknn, klaR, knitr, MASS, mda, mgcv, modeldata,
        nestedmodels, nnet, parsnip (>= 0.1.6), pkgload, pls, QSARdata,
        randomForest, ranger, RANN, recipes (>= 0.2.0), rmarkdown,
        rpart, rsample, RSpectra, sparklyr, survival (>= 3.2-10),
        testthat (>= 3.0.0), TH.data, tidyr, usethis (>= 1.5.0),
        xgboost (>= 1.3.2.1), xrf
VignetteBuilder: knitr
Config/Needs/check: bioc::mixOmics
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-04-11 09:47:41 UTC; juliasilge
Author: Joyce Cahoon [aut] (<https://orcid.org/0000-0001-7217-4702>),
  Davis Vaughan [aut],
  Max Kuhn [aut],
  Alex Hayes [aut],
  Julia Silge [cre, aut] (<https://orcid.org/0000-0002-3671-836X>),
  Posit, PBC [cph, fnd]
Maintainer: Julia Silge <julia.silge@posit.co>
Repository: CRAN
Date/Publication: 2024-04-11 10:30:02 UTC
Built: R 4.4.0; ; 2024-04-30 20:38:08 UTC; unix
