# Generated by roxygen2: do not edit by hand

S3method(as.character,dev_topic)
S3method(axe_call,C5.0)
S3method(axe_call,KMeansCluster)
S3method(axe_call,NaiveBayes)
S3method(axe_call,bart)
S3method(axe_call,classbagg)
S3method(axe_call,default)
S3method(axe_call,earth)
S3method(axe_call,elnet)
S3method(axe_call,fda)
S3method(axe_call,flexsurvreg)
S3method(axe_call,gam)
S3method(axe_call,gausspr)
S3method(axe_call,glm)
S3method(axe_call,glmnet)
S3method(axe_call,kknn)
S3method(axe_call,ksvm)
S3method(axe_call,lm)
S3method(axe_call,mda)
S3method(axe_call,mixo_pls)
S3method(axe_call,mixo_spls)
S3method(axe_call,ml_model)
S3method(axe_call,model_fit)
S3method(axe_call,multnet)
S3method(axe_call,nested_model_fit)
S3method(axe_call,nnet)
S3method(axe_call,randomForest)
S3method(axe_call,ranger)
S3method(axe_call,rda)
S3method(axe_call,regbagg)
S3method(axe_call,rpart)
S3method(axe_call,sclass)
S3method(axe_call,survbagg)
S3method(axe_call,survreg)
S3method(axe_call,survreg.penal)
S3method(axe_call,train)
S3method(axe_call,train.recipe)
S3method(axe_call,xgb.Booster)
S3method(axe_call,xrf)
S3method(axe_ctrl,C5.0)
S3method(axe_ctrl,classbagg)
S3method(axe_ctrl,default)
S3method(axe_ctrl,gam)
S3method(axe_ctrl,ml_model)
S3method(axe_ctrl,model_fit)
S3method(axe_ctrl,nested_model_fit)
S3method(axe_ctrl,randomForest)
S3method(axe_ctrl,regbagg)
S3method(axe_ctrl,rpart)
S3method(axe_ctrl,survbagg)
S3method(axe_ctrl,train)
S3method(axe_ctrl,train.recipe)
S3method(axe_data,NaiveBayes)
S3method(axe_data,classbagg)
S3method(axe_data,coxph)
S3method(axe_data,default)
S3method(axe_data,earth)
S3method(axe_data,gam)
S3method(axe_data,gausspr)
S3method(axe_data,glm)
S3method(axe_data,kproto)
S3method(axe_data,ksvm)
S3method(axe_data,mixo_pls)
S3method(axe_data,mixo_spls)
S3method(axe_data,ml_model)
S3method(axe_data,model_fit)
S3method(axe_data,nested_model_fit)
S3method(axe_data,regbagg)
S3method(axe_data,rpart)
S3method(axe_data,survbagg)
S3method(axe_data,survreg)
S3method(axe_data,survreg.penal)
S3method(axe_data,train)
S3method(axe_data,train.recipe)
S3method(axe_env,"function")
S3method(axe_env,classbagg)
S3method(axe_env,coxph)
S3method(axe_env,default)
S3method(axe_env,fda)
S3method(axe_env,flexsurvreg)
S3method(axe_env,formula)
S3method(axe_env,gam)
S3method(axe_env,gausspr)
S3method(axe_env,glm)
S3method(axe_env,kknn)
S3method(axe_env,lda)
S3method(axe_env,lm)
S3method(axe_env,mda)
S3method(axe_env,model_fit)
S3method(axe_env,nested_model_fit)
S3method(axe_env,nnet)
S3method(axe_env,qda)
S3method(axe_env,quosure)
S3method(axe_env,randomForest)
S3method(axe_env,rda)
S3method(axe_env,recipe)
S3method(axe_env,regbagg)
S3method(axe_env,rpart)
S3method(axe_env,sclass)
S3method(axe_env,step)
S3method(axe_env,step_arrange)
S3method(axe_env,step_bagimpute)
S3method(axe_env,step_filter)
S3method(axe_env,step_geodist)
S3method(axe_env,step_impute_bag)
S3method(axe_env,step_impute_knn)
S3method(axe_env,step_interact)
S3method(axe_env,step_knnimpute)
S3method(axe_env,step_mutate)
S3method(axe_env,step_ratio)
S3method(axe_env,step_slice)
S3method(axe_env,survbagg)
S3method(axe_env,survreg)
S3method(axe_env,survreg.penal)
S3method(axe_env,terms)
S3method(axe_env,train)
S3method(axe_env,train.recipe)
S3method(axe_env,xgb.Booster)
S3method(axe_env,xrf)
S3method(axe_fitted,C5.0)
S3method(axe_fitted,KMeansCluster)
S3method(axe_fitted,bart)
S3method(axe_fitted,default)
S3method(axe_fitted,earth)
S3method(axe_fitted,fda)
S3method(axe_fitted,gam)
S3method(axe_fitted,gausspr)
S3method(axe_fitted,glm)
S3method(axe_fitted,kknn)
S3method(axe_fitted,kproto)
S3method(axe_fitted,ksvm)
S3method(axe_fitted,lm)
S3method(axe_fitted,mda)
S3method(axe_fitted,mixo_pls)
S3method(axe_fitted,mixo_spls)
S3method(axe_fitted,ml_model)
S3method(axe_fitted,model_fit)
S3method(axe_fitted,nested_model_fit)
S3method(axe_fitted,nnet)
S3method(axe_fitted,ranger)
S3method(axe_fitted,recipe)
S3method(axe_fitted,train)
S3method(axe_fitted,train.recipe)
S3method(weigh,default)
S3method(weigh,ksvm)
S3method(weigh,model_fit)
export(axe_call)
export(axe_ctrl)
export(axe_data)
export(axe_env)
export(axe_fitted)
export(butcher)
export(locate)
export(new_model_butcher)
export(weigh)
